@@ -1,15 +1,13 @@
-# -*- coding: ascii -*-
-
 ##
-# <p> Portions copyright (c) 2008-2012 Stephen John Machin, Lingfo Pty Ltd</p>
-# <p>This module is part of the xlrd package, which is released under a BSD-style licence.</p>
+# Portions copyright (c) 2008-2012 Stephen John Machin, Lingfo Pty Ltd
+# This module is part of the xlrd package, which is released under a BSD-style licence.
 ##
 
 from __future__ import print_function, unicode_literals
 
 DEBUG = 0
 
-import sys, zipfile, pprint
+import sys
 import re
 from .timemachine import *
 from .book import Book, Name
@@ -65,7 +63,7 @@ def split_tag(tag):
 
 def augment_keys(adict, uri):
     # uri must already be enclosed in {}
-    for x in adict.keys():
+    for x in list(adict.keys()):
         adict[uri + x] = adict[x]
 
 _UPPERCASE_1_REL_INDEX = {} # Used in fast conversion of column names (e.g. "XFD") to indices (16383)
@@ -123,34 +121,13 @@ def unescape(s,
         return subber(repl, s)
     return s
 
-if python_version < (2, 2):
-    def strip_xml_ws(s,
-        ):
-        n = len(s)
-        spos = 0
-        while spos < n and s[spos] in XML_WHITESPACE:
-            spos += 1
-        epos = n - 1
-        while epos >= spos and s[epos] in XML_WHITESPACE:
-            epos -= 1
-        return s[spos:epos+1]
-
-    def cooked_text(self, elem):
-        t = elem.text
-        if t is None:
-            return ''
-        if elem.get(XML_SPACE_ATTR) != 'preserve':
-            t = strip_xml_ws(t)
-        return unicode(unescape(t))
-else:
-
-    def cooked_text(self, elem):
-        t = elem.text
-        if t is None:
-            return ''
-        if elem.get(XML_SPACE_ATTR) != 'preserve':
-            t = t.strip(XML_WHITESPACE)
-        return unicode(unescape(t))
+def cooked_text(self, elem):
+    t = elem.text
+    if t is None:
+        return ''
+    if elem.get(XML_SPACE_ATTR) != 'preserve':
+        t = t.strip(XML_WHITESPACE)
+    return unicode(unescape(t))
 
 def get_text_from_si_or_is(self, elem, r_tag=U_SSML12+'r', t_tag=U_SSML12 +'t'):
     "Returns unescaped unicode"
@@ -182,7 +159,7 @@ def map_attributes(amap, elem, obj):
 
 def cnv_ST_Xstring(s):
     if s is None: return ""
-    return unicode(s)
+    return ensure_unicode(s)
 
 def cnv_xsd_unsignedInt(s):
     if not s:
@@ -375,7 +352,7 @@ class X12Book(X12General):
         # print elem.attrib
         rid = elem.get(U_ODREL + 'id')
         sheetId = int(elem.get('sheetId'))
-        name = unescape(unicode(elem.get('name')))
+        name = unescape(ensure_unicode(elem.get('name')))
         reltype = self.relid2reltype[rid]
         target = self.relid2path[rid]
         if self.verbosity >= 2:
@@ -440,7 +417,7 @@ class X12SST(X12General):
             self.dumpout('Entries in SST: %d', len(sst))
         if self.verbosity >= 3:
             for x, s in enumerate(sst):
-                print("SST x=%d s=%r" % (x, s))
+                fprintf(self.logfile, "SST x=%d s=%r\n", x, s)
 
     def process_stream_findall(self, stream, heading=None):
         if self.verbosity >= 2 and heading is not None:
@@ -468,7 +445,7 @@ class X12Styles(X12General):
         self.xf_counts = [0, 0]
         self.xf_type = None
         self.fmt_is_date = {}
-        for x in range(14, 23) + range(45, 48): #### hard-coding FIX ME ####
+        for x in list(range(14, 23)) + list(range(45, 48)): #### hard-coding FIX ME ####
             self.fmt_is_date[x] = 1
         # dummy entry for XF 0 in case no Styles section
         self.bk._xf_index_to_xl_type_map[0] = 2
@@ -481,7 +458,7 @@ class X12Styles(X12General):
         self.xf_type = 1
 
     def do_numfmt(self, elem):
-        formatCode = unicode(elem.get('formatCode'))
+        formatCode = ensure_unicode(elem.get('formatCode'))
         numFmtId = int(elem.get('numFmtId'))
         is_date = is_date_format_string(self.bk, formatCode)
         self.fmt_is_date[numFmtId] = is_date
@@ -720,7 +697,6 @@ def open_workbook_2007_xml(
     component_names,
     logfile=sys.stdout,
     verbosity=0,
-    pickleable=1,
     use_mmap=0,
     formatting_info=0,
     on_demand=0,
@@ -730,7 +706,6 @@ def open_workbook_2007_xml(
     bk = Book()
     bk.logfile = logfile
     bk.verbosity = verbosity
-    bk.pickleable = pickleable
     bk.formatting_info = formatting_info
     if formatting_info:
         raise NotImplementedError("formatting_info=True not yet implemented")
